==> msmtp-scripts-1.2.4.tar.gz: msmtp-scripts-1.2.4/tests/scripts/t00510-test-missing-configs-dirs.sh <==
#!/bin/sh
#
# msmtp-scripts test framework
#
#    Copyright (C) 2019 Daniel F. Dickinson <cshored@thecshore.com>
#
#    This program is free software: you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation, either version 3 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program.  If not, see <http://www.gnu.org/licenses/>.
#

OTS=SUCCESS

export MSMTP_SKIP_CONF=true
export MSMTP_OVERRIDE_CONF=./tmp/msmtpq-ng-no-log.rc

rm -rf ./tmp/msmtp.queue/*
rm -f ./tmp/msmtp.queue.log
rm -f ./tmp/missing-log-dir.txt

export LOG=/nonexistant/msmtpq-ng.log

TS=PASS

if echo "Subject: test missing log dir
       
Mising log dir"| /usr/bin/msmtpq-ng root 2>./tmp/missing-log-dir.txt; then
	TS=FAIL
	OTS=FAIL
fi

echo "$TS: Missing log dir generates error"

TS=PASS

if ! test -s ./tmp/missing-log-dir.txt; then
	TS=FAIL
	OTS=FAIL
fi

echo "$TS: Missing log dir error message displayed"

TS=PASS

rm -f ./tmp/missing-log-dir.txt

if /usr/bin/msmtpq-ng-queue 2>./tmp/missing-log-dir.txt; then
	TS=FAIL
	OTS=FAIL
fi

echo "$TS: Missing log dir for queue generates error for queue"

TS=PASS

if ! test -s ./tmp/missing-log-dir.txt; then
	TS=FAIL
	OTS=FAIL
fi

echo "$TS: Missing log dir error message displayed for queue"

TS=PASS

if [ "$USER" = "travis" ] || [ "$USER" = "debian" ]; then
	rm -f ~/.msmtpq-ng.rc
	cp ./tmp/msmtpq-fail.rc ~/.msmtpq-ng.rc

	unset MSMTP_SKIP_CONF
	unset MSMTP_OVERRIDE_CONF
	export MSMTP_SKIP_CONF MSMTP_OVERRIDE_CONF

printf "Subject: test 'default' location config\n\nTest a config in a default location\n" | /usr/bin/msmtpq-ng && {
		TS=FAIL
		OTS=FAIL
	}
else
	TS=SKIPPED
fi

echo "$TS: Config in a 'default' location succeeds"

if [ "$TS" != "SKIPPED" ]; then
	/usr/bin/msmtpq-ng-queue || {
		TS=FAIL
		OTS=FAIL
	}
fi

echo "$TS: Config in a 'default' location succeeds for queue list"

export MSMTP_SKIP_CONF=true
export MSMTP_OVERRIDE_CONF=./tmp/msmtpq-ng-no-msmtp.rc

TS=PASS

if echo "Subject: test missing msmtp exe
       
Missing executable"| /usr/bin/msmtpq-ng root 2>./tmp/missing-binary.txt; then
	TS=FAIL
	OTS=FAIL
fi

echo "$TS: Missing msmtp binary generates error"

TS=PASS

if ! test -s ./tmp/missing-binary.txt; then
	TS=FAIL
	OTS=FAIL
fi

echo "$TS: Missing binary message shown"

export MSMTP_OVERRIDE_CONF=./tmp/msmtpq-ng-new-qdir.rc
rm -rf ./tmp/q2

TS=PASS

if ! echo "Subject: test new queue dir
       
Test using a queue dir that doesn't exist yet."| /usr/bin/msmtpq-ng root; then
	TS=FAIL
	OTS=FAIL
fi

echo "$TS: Using a new queue dir succeeds"

TS=PASS

if [ -z "$(ls -A ./tmp/q2/* 2>/dev/null)" ]; then
	TS=FAIL
	OTS=FAIL
fi

echo "$TS: A new queue dir gets used."

rm -rf ./tmp/q2

if ! /usr/bin/msmtpq-ng-queue >./tmp/new-queue-dir-list-queue.txt; then
	TS=FAIL
	OTS=FAIL
fi

echo "$TS: Using a new queue dir succeeds for list queue"

TS=PASS

if [ ! -s ./tmp/new-queue-dir-list-queue.txt ]; then
	TS=FAIL
	OTS=FAIL
fi

echo "$TS: A new queue dir gets used for list queue"

export MSMTP_OVERRIDE_CONF=./tmp/msmtpq-ng-new-lockdir.rc
rm -rf ./tmp/q3

TS=PASS

if ! echo "Subject: test new lock dir
       
Test using a lock dir that doesn't exist yet."| /usr/bin/msmtpq-ng root; then
	TS=FAIL
	OTS=FAIL
fi

echo "$TS: Using a new lock dir succeeds"

rm -rf ./tmp/q3 

if ! /usr/bin/msmtpq-ng-queue; then
	TS=FAIL
	OTS=FAIL
fi

echo "$TS: Using a new lock dir succeeds for list queue"

export MSMTP_OVERRIDE_CONF=./tmp/msmtpq-ng-flock.rc
unset LOCK_CMD
export LOCK_CMD
OLDPATH="${PATH}"
export OLDPATH
export PATH="$(pwd)/tests/scripts:${OLDPATH}"

TS=PASS

if ! echo "Subject: test flock substitute
 
Test using flock substitute."| /usr/bin/msmtpq-ng root; then
	TS=FAIL
	OTS=FAIL
fi

echo "$TS: Using a flock substitute succeeds"

TS=PASS

if ! /usr/bin/msmtpq-ng-queue; then
	TS=FAIL
	OTS=FAIL
fi

echo "$TS: Using a flock substitute succeeds for list queue"

export PATH="/nonexistant"

TS=PASS

if echo "Subject: test missing lock command
       
Test missing lock command."| /usr/bin/msmtpq-ng root; then
	TS=FAIL
	OTS=FAIL
fi

echo "$TS: Missing lock command fails"

TS=PASS

export MSMTPQ_NG=/usr/bin/msmtpq-ng

if /usr/bin/msmtpq-ng-queue; then
	TS=FAIL
	OTS=FAIL
fi

echo "$TS: Missing lock command fails for list queue"

export PATH="${OLDPATH}"

TS=PASS

if echo "Subject: test missing addressee
       
Test missing addressee command."| /usr/bin/msmtpq-ng; then
	TS=FAIL
	OTS=FAIL
fi

echo "$TS: Missing addressee fails"

TS=PASS

export MSMTP_OVERRIDE_CONF=./tmp/msmtpq-ng-missing-ng.rc

/usr/bin/msmtpq-ng-queue
MQNQRC=$?

if [ "$MQNQRC" != "72" ]; then
	TS=FAIL
	OTS=FAIL
fi

echo "$TS: For msmtpq-ng-queue a missing msmtpq-ng errors out"

TS=PASS

export MSMTP_MTA_OVERRIDE_CONF=./tmp/msmtpq-ng-missing-ng.rc
export MSMTPQ_NG_QUEUE=/nonexistant
/usr/sbin/msmtpq-ng-queue-mta
MQNQRC=$?

if [ "$MQNQRC" != "72" ]; then
	TS=FAIL
	OTS=FAIL
fi

echo "$TS: For msmtpq-ng-queue-mta a missing msmtpq-ng-queue errors out"

TS=PASS

export MSMTP_MTA_OVERRIDE_CONF=./tmp/msmtpq-ng-missing-ng.rc
export MSMTPQ_NG=/nonexistant

echo "Subject: test missing mstmpq-ng

Test missing msmtpq-ng for mta" | /usr/sbin/msmtpq-ng-mta root
MQNQRC=$?

if [ "$MQNQRC" != "72" ]; then
	TS=FAIL
	OTS=FAIL
fi

echo "$TS: For msmtpq-ng-mta a missing msmtpq-ng errors out"

if [ "$OTS" = "FAIL" ]; then
	exit 3
else
	exit 0
fi

==> msmtp-scripts-1.2.5.1.tar.gz: msmtp-scripts-1.2.5.1/tests/scripts/t00510-test-missing-configs-dirs.sh <==
#!/bin/sh
#
# msmtp-scripts test framework
#
#    Copyright (C) 2019 Daniel F. Dickinson <cshored@thecshore.com>
#
#    This program is free software: you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation, either version 3 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program.  If not, see <http://www.gnu.org/licenses/>.
#

OTS=SUCCESS

export MSMTP_SKIP_CONF=true
export MSMTP_OVERRIDE_CONF=./tmp/msmtpq-ng-no-log.rc

rm -rf ./tmp/msmtp.queue/*
rm -f ./tmp/msmtp.queue.log
rm -f ./tmp/missing-log-dir.txt

export LOG=/nonexistant/msmtpq-ng.log

TS=PASS

if echo "Subject: test missing log dir

Missing log dir"| MSMTP_SKIP_CONF=true MSMTP_OVERRIDE_CONF=${MSMTP_OVERRIDE_CONF} ${KCOV_OUTSIDE}13-1 /usr/bin/msmtpq-ng -kcov "${KCOV_BASE}13-1" root 2>./tmp/missing-log-dir.txt; then
	TS=FAIL
	OTS=FAIL
fi

echo "$TS: Missing log dir generates error"

TS=PASS

if ! test -s ./tmp/missing-log-dir.txt; then
	TS=FAIL
	OTS=FAIL
fi

echo "$TS: Missing log dir error message displayed"

TS=PASS

rm -f ./tmp/missing-log-dir.txt

if MSMTP_SKIP_CONF=true MSMTP_OVERRIDE_CONF=${MSMTP_OVERRIDE_CONF} ${KCOV_OUTSIDE}13-2 /usr/bin/msmtpq-ng-queue -kcov "${KCOV_BASE}13-2" 2>./tmp/missing-log-dir.txt; then
	TS=FAIL
	OTS=FAIL
fi

echo "$TS: Missing log dir for queue generates error for queue"

TS=PASS

if ! test -s ./tmp/missing-log-dir.txt; then
	TS=FAIL
	OTS=FAIL
fi

echo "$TS: Missing log dir error message displayed for queue"

rm -rf ./tmp/msmtp.queue/*
rm -f ./tmp/msmtp.queue.log
rm -f ./tmp/missing-log-dir.txt

TS=PASS

if [ "$USER" = "travis" ] || [ "$USER" = "debian" ]; then
	rm -f ~/.msmtpq-ng.rc
	cp ./tmp/msmtpq-fail.rc ~/.msmtpq-ng.rc

	unset MSMTP_SKIP_CONF
	unset MSMTP_OVERRIDE_CONF
	export MSMTP_SKIP_CONF MSMTP_OVERRIDE_CONF

printf "Subject: test 'default' location config\n\nTest a config in a default location\n" | MSMTP_SKIP_CONF=true MSMTP_OVERRIDE_CONF=${MSMTP_OVERRIDE_CONF} ${KCOV_OUTSIDE}13-3 /usr/bin/msmtpq-ng -kcov "${KCOV_BASE}13-3" && {
		TS=FAIL
		OTS=FAIL
	}
else
	TS=SKIPPED
fi

echo "$TS: Config in a 'default' location succeeds"

if [ "$TS" != "SKIPPED" ]; then
	/usr/bin/msmtpq-ng-queue || {
		TS=FAIL
		OTS=FAIL
	}
fi

echo "$TS: Config in a 'default' location succeeds for queue list"

export MSMTP_SKIP_CONF=true
export MSMTP_OVERRIDE_CONF=./tmp/msmtpq-ng-no-msmtp.rc

TS=PASS

if echo "Subject: test missing msmtp exe

Missing executable"| MSMTP_SKIP_CONF=true MSMTP_OVERRIDE_CONF=${MSMTP_OVERRIDE_CONF} ${KCOV_OUTSIDE}13-4 /usr/bin/msmtpq-ng -kcov "${KCOV_BASE}13-4" root 2>./tmp/missing-binary.txt; then
	TS=FAIL
	OTS=FAIL
fi

echo "$TS: Missing msmtp binary generates error"

TS=PASS

if ! test -s ./tmp/missing-binary.txt; then
	TS=FAIL
	OTS=FAIL
fi

echo "$TS: Missing binary message shown"

rm -rf ./tmp/msmtp.queue/*
rm -f ./tmp/msmtp.queue.log
rm -f ./tmp/missing-binary.txt

export MSMTP_OVERRIDE_CONF=./tmp/msmtpq-ng-new-qdir.rc
rm -rf ./tmp/q2

TS=PASS

if ! echo "Subject: test new queue dir

Test using a queue dir that doesn't exist yet."| MSMTP_SKIP_CONF=true MSMTP_OVERRIDE_CONF=${MSMTP_OVERRIDE_CONF} ${KCOV_OUTSIDE}13-5 /usr/bin/msmtpq-ng -kcov "${KCOV_BASE}13-5" root; then
	TS=FAIL
	OTS=FAIL
fi

echo "$TS: Using a new queue dir succeeds"

TS=PASS

if [ -z "$(find ./tmp/q2/msmtp.queue -maxdepth 1 -mindepth 1|head -n1)" ]; then
	TS=FAIL
	OTS=FAIL
fi

echo "$TS: A new queue dir gets used."

rm -rf ./tmp/q2

if ! MSMTP_SKIP_CONF=true MSMTP_OVERRIDE_CONF=${MSMTP_OVERRIDE_CONF} ${KCOV_OUTSIDE}13-6 /usr/bin/msmtpq-ng-queue -kcov "${KCOV_BASE}13-6">./tmp/new-queue-dir-list-queue.txt; then
	TS=FAIL
	OTS=FAIL
fi

echo "$TS: Using a new queue dir succeeds for list queue"

TS=PASS

if [ ! -s ./tmp/new-queue-dir-list-queue.txt ]; then
	TS=FAIL
	OTS=FAIL
fi

echo "$TS: A new queue dir gets used for list queue"

rm -rf ./tmp/q2
rm -f ./tmp/msmtp.queue.log
rm -f ./tmp/new-queue-dir-list-queue.txt


export MSMTP_OVERRIDE_CONF=./tmp/msmtpq-ng-new-lockdir.rc
rm -rf ./tmp/q3

TS=PASS

if ! echo "Subject: test new lock dir

Test using a lock dir that doesn't exist yet."| MSMTP_SKIP_CONF=true MSMTP_OVERRIDE_CONF=${MSMTP_OVERRIDE_CONF} ${KCOV_OUTSIDE}13-7 /usr/bin/msmtpq-ng -kcov "${KCOV_BASE}13-7" root; then
	TS=FAIL
	OTS=FAIL
fi

echo "$TS: Using a new lock dir succeeds"

rm -rf ./tmp/q3

if ! MSMTP_SKIP_CONF=true MSMTP_OVERRIDE_CONF=${MSMTP_OVERRIDE_CONF} ${KCOV_OUTSIDE}13-8 /usr/bin/msmtpq-ng-queue -kcov "${KCOV_BASE}13-8"; then
	TS=FAIL
	OTS=FAIL
fi

echo "$TS: Using a new lock dir succeeds for list queue"

rm -rf ./tmp/q3
rm -f ./tmp/msmtp.queue.log

export MSMTP_OVERRIDE_CONF=./tmp/msmtpq-ng-flock.rc
unset LOCK_CMD
export LOCK_CMD
OLDPATH="${PATH}"
export OLDPATH
PATH="$(pwd)/tests/scripts:${OLDPATH}"
export PATH

TS=PASS

if ! echo "Subject: test flock substitute

Test using flock substitute."| MSMTP_SKIP_CONF=true MSMTP_OVERRIDE_CONF=${MSMTP_OVERRIDE_CONF} ${KCOV_OUTSIDE}13-9 /usr/bin/msmtpq-ng -kcov "${KCOV_BASE}13-9" root; then
	TS=FAIL
	OTS=FAIL
fi

echo "$TS: Using a flock substitute succeeds"

TS=PASS

if ! MSMTP_SKIP_CONF=true MSMTP_OVERRIDE_CONF=${MSMTP_OVERRIDE_CONF} ${KCOV_OUTSIDE}13-10 /usr/bin/msmtpq-ng-queue -kcov "${KCOV_BASE}13-10"; then
	TS=FAIL
	OTS=FAIL
fi

echo "$TS: Using a flock substitute succeeds for list queue"

rm -rf ./tmp/msmtp.queue
rm -f ./tmp/msmtp.queue.log


export PATH="/nonexistant"

TS=PASS

if echo "Subject: test missing lock command

Test missing lock command."| MSMTP_SKIP_CONF=true MSMTP_OVERRIDE_CONF=${MSMTP_OVERRIDE_CONF} ${KCOV_OUTSIDE}13-11 /usr/bin/msmtpq-ng -kcov "${KCOV_BASE}13-11" root; then
	TS=FAIL
	OTS=FAIL
fi

echo "$TS: Missing lock command fails"

rm -rf ./tmp/msmtp.queue
rm -f ./tmp/msmtp.queue.log

TS=PASS

export MSMTPQ_NG=/usr/bin/msmtpq-ng

if  MSMTP_SKIP_CONF=true MSMTP_OVERRIDE_CONF=${MSMTP_OVERRIDE_CONF} ${KCOV_OUTSIDE}13-12 /usr/bin/msmtpq-ng-queue -kcov "${KCOV_BASE}13-12"; then
	TS=FAIL
	OTS=FAIL
fi

echo "$TS: Missing lock command fails for list queue"

rm -rf ./tmp/msmtp.queue
rm -f ./tmp/msmtp.queue.log

export PATH="${OLDPATH}"

TS=PASS

if echo "Subject: test missing addressee

Test missing addressee command."| MSMTP_SKIP_CONF=true MSMTP_OVERRIDE_CONF=${MSMTP_OVERRIDE_CONF} ${KCOV_OUTSIDE}13-13 /usr/bin/msmtpq-ng -kcov "${KCOV_BASE}13-13"; then
	TS=FAIL
	OTS=FAIL
fi

echo "$TS: Missing addressee fails"

rm -rf ./tmp/msmtp.queue
rm -f ./tmp/msmtp.queue.log

TS=PASS

export MSMTP_OVERRIDE_CONF=./tmp/msmtpq-ng-missing-ng.rc

 MSMTP_SKIP_CONF=true MSMTP_OVERRIDE_CONF=${MSMTP_OVERRIDE_CONF} ${KCOV_OUTSIDE}13-14 /usr/bin/msmtpq-ng-queue -kcov "${KCOV_BASE}13-14"
MQNQRC=$?

if [ "$MQNQRC" != "72" ]; then
	TS=FAIL
	OTS=FAIL
fi

echo "$TS: For msmtpq-ng-queue a missing msmtpq-ng errors out"

rm -rf ./tmp/msmtp.queue
rm -f ./tmp/msmtp.queue.log

TS=PASS

export MSMTP_MTA_OVERRIDE_CONF=./tmp/msmtpq-ng-missing-ng.rc
export MSMTPQ_NG_QUEUE=/nonexistant
MSMTP_SKIP_CONF=true MSMTP_OVERRIDE_CONF=${MSMTP_OVERRIDE_CONF} ${KCOV_OUTSIDE}13-15 /usr/sbin/msmtpq-ng-queue-mta -kcov "${KCOV_BASE}13-15"
MQNQRC=$?

if [ "$MQNQRC" != "72" ]; then
	TS=FAIL
	OTS=FAIL
fi

echo "$TS: For msmtpq-ng-queue-mta a missing msmtpq-ng-queue errors out"

rm -rf ./tmp/msmtp.queue
rm -f ./tmp/msmtp.queue.log

TS=PASS

export MSMTP_MTA_OVERRIDE_CONF=./tmp/msmtpq-ng-missing-ng.rc
export MSMTPQ_NG=/nonexistant

echo "Subject: test missing mstmpq-ng

Test missing msmtpq-ng for mta" | MSMTP_SKIP_CONF=true MSMTP_OVERRIDE_CONF=${MSMTP_OVERRIDE_CONF} ${KCOV_OUTSIDE}13-16 /usr/sbin/msmtpq-ng-mta -kcov "${KCOV_BASE}13-16" root
MQNQRC=$?

if [ "$MQNQRC" != "72" ]; then
	TS=FAIL
	OTS=FAIL
fi

echo "$TS: For msmtpq-ng-mta a missing msmtpq-ng errors out"

rm -rf ./tmp/msmtp.queue
rm -f ./tmp/msmtp.queue.log

if [ "$OTS" = "FAIL" ]; then
	exit 3
else
	exit 0
fi
